@@ -1,4 +1,4 @@
-from ucloud.lib.api import UcloudAPI
+from ucloudbiz.server.lib.api import UcloudAPI
 
 class queryAsyncJobResult(UcloudAPI):
 
